@@ -482,7 +482,7 @@ bool DCrumbEdit::appendCrumb(const QString &text)
 
     format.setText(text);
 
-    return appendCrumb(text);
+    return appendCrumb(format);
 }
 
 bool DCrumbEdit::containCrumb(const QString &text) const
@@ -660,7 +660,12 @@ void DCrumbEdit::keyPressEvent(QKeyEvent *event)
     if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
         D_D(DCrumbEdit);
 
-        d->makeCrumb();
+        bool result = d->makeCrumb();
+        if (!result)
+            event->ignore();
+
+    } else if (event->key() == Qt::Key_Escape) {
+        event->ignore();
     } else {
         QTextEdit::keyPressEvent(event);
     }
