@@ -94,6 +94,12 @@ public:
     D_DECLARE_PUBLIC(DSimpleListView)
 };
 
+/*!
+ * \~chinese \class DSimpleListView
+ * \~chinese \brief DSimpleListView 是 deepin 基于 QWidget 从零绘制的列表控件。
+ * \~chinese \brief 开发者只要懂得怎么使用 QPainter 进行图形绘制，开发者就可以在 DSimpleListItem 中绘制任意行内容，包括文本、图片、任意控件甚至每行都可以画一个小电影，而代码的复杂度不会随着绘制行内容而发生变化，所有的行内容都源于怎么使用 QPainter。
+ */
+
 DSimpleListView::DSimpleListView(QWidget *parent) : QWidget(parent), DObject(*new DSimpleListViewPrivate(this))
 {
     D_D(DSimpleListView);
@@ -181,6 +187,9 @@ DSimpleListView::~DSimpleListView()
     delete d->hideScrollbarTimer;
 }
 
+/*!
+ * \~chinese \brief 设置行高
+ */
 void DSimpleListView::setRowHeight(int height)
 {
     D_D(DSimpleListView);
@@ -189,6 +198,9 @@ void DSimpleListView::setRowHeight(int height)
     d->scrollUnit = d->rowHeight;
 }
 
+/*!
+ * \~chinese \brief 设置列标题信息
+ */
 void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> widths, int height)
 {
     D_D(DSimpleListView);
@@ -216,6 +228,11 @@ void DSimpleListView::setColumnTitleInfo(QList<QString> titles, QList<int> width
     d->titleHeight = height;
 }
 
+/*!
+ * \~chinese \brief 设置列隐藏标志
+ * \~chinese \param toggleHideFlags 用于控制列的隐藏标志，用于切换显示/隐藏。
+ * \~chinese \param visibleColumnIndex 列始终可见的列索引，默认值为 -1，表示列始终不可见。
+ */
 void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibleColumnIndex)
 {
     D_D(DSimpleListView);
@@ -231,6 +248,9 @@ void DSimpleListView::setColumnHideFlags(QList<bool> toggleHideFlags, int visibl
     }
 }
 
+/*!
+ * \~chinese \brief 设置列排序算法
+ */
 void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithms, int sortColumn, bool descendingSort)
 {
     D_D(DSimpleListView);
@@ -247,6 +267,9 @@ void DSimpleListView::setColumnSortingAlgorithms(QList<SortAlgorithm> *algorithm
     d->defaultSortingOrder = descendingSort;
 }
 
+/*!
+ * \~chinese \brief 设置搜索算法
+ */
 void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
 {
     D_D(DSimpleListView);
@@ -254,6 +277,9 @@ void DSimpleListView::setSearchAlgorithm(SearchAlgorithm algorithm)
     d->searchAlgorithm = algorithm;
 }
 
+/*!
+ * \~chinese \brief 设置圆角半径
+ */
 void DSimpleListView::setClipRadius(int radius)
 {
     D_D(DSimpleListView);
@@ -261,6 +287,12 @@ void DSimpleListView::setClipRadius(int radius)
     d->clipRadius = radius;
 }
 
+/*!
+ * \~chinese \brief 设置边角细节
+ * \~chinese \param enableFrame 是否绘制边角
+ * \~chinese \param color 边角颜色
+ * \~chinese \param opacity 不透明度
+ */
 void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
 {
     D_D(DSimpleListView);
@@ -270,6 +302,9 @@ void DSimpleListView::setFrame(bool enableFrame, QColor color, double opacity)
     frameOpacity = opacity;
 }
 
+/*!
+ * \~chinese \brief 添加 DSimpleListItem 列表到视图中
+ */
 void DSimpleListView::addItems(QList<DSimpleListItem*> items)
 {
     D_D(DSimpleListView);
@@ -288,6 +323,9 @@ void DSimpleListView::addItems(QList<DSimpleListItem*> items)
     repaint();
 }
 
+/*!
+ * \~chinese \brief 删除一个列表项
+ */
 void DSimpleListView::removeItem(DSimpleListItem* item)
 {
     D_D(DSimpleListView);
@@ -302,6 +340,9 @@ void DSimpleListView::removeItem(DSimpleListItem* item)
     repaint();
 }
 
+/*!
+ * \~chinese \brief 删除所有列表项
+ */
 void DSimpleListView::clearItems()
 {
     D_D(DSimpleListView);
@@ -313,6 +354,10 @@ void DSimpleListView::clearItems()
     d->renderItems->clear();
 }
 
+/*!
+ * \~chinese \brief 添加 DSimpleListItem 列表以在视图中选择效果
+ * \~chinese \param recordLastSelection 为 true 则清除最后一个选择项
+ */
 void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLastSelection)
 {
     D_D(DSimpleListView);
@@ -326,6 +371,9 @@ void DSimpleListView::addSelections(QList<DSimpleListItem*> items, bool recordLa
     }
 }
 
+/*!
+ * \~chinese \brief 移除所有选择项
+ */
 void DSimpleListView::clearSelections(bool clearLastSelection)
 {
     D_D(DSimpleListView);
@@ -338,6 +386,9 @@ void DSimpleListView::clearSelections(bool clearLastSelection)
     }
 }
 
+/*!
+ * \~chinese \brief 获取所有选择项
+ */
 QList<DSimpleListItem*> DSimpleListView::getSelections()
 {
     D_D(DSimpleListView);
@@ -345,6 +396,9 @@ QList<DSimpleListItem*> DSimpleListView::getSelections()
     return *d->selectionItems;
 }
 
+/*!
+ * \~chinese \brief 刷新所有项
+ */
 void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
 {
     D_D(DSimpleListView);
@@ -407,6 +461,9 @@ void DSimpleListView::refreshItems(QList<DSimpleListItem*> items)
     repaint();
 }
 
+/*!
+ * \~chinese \brief 搜索
+ */
 void DSimpleListView::search(QString content)
 {
     D_D(DSimpleListView);
@@ -427,24 +484,33 @@ void DSimpleListView::search(QString content)
     repaint();
 }
 
+/*!
+ * \~chinese \brief 设置单一选择
+ */
 void DSimpleListView::setSingleSelect(bool singleSelect)
 {
     D_D(DSimpleListView);
-        
+
     d->isSingleSelect = singleSelect;
 }
 
+/*!
+ * \~chinese \brief 单击空白区域时保持选择项
+ */
 void DSimpleListView::keepSelectWhenClickBlank(bool keep)
 {
     D_D(DSimpleListView);
-    
+
     d->isKeepSelectWhenClickBlank = keep;
 }
 
+/*!
+ * \~chinese \brief 选择所有列表项
+ */
 void DSimpleListView::selectAllItems()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         // Record old render offset to control scrollbar whether display.
         d->oldRenderOffset = d->renderOffset;
@@ -462,6 +528,9 @@ void DSimpleListView::selectAllItems()
 
 }
 
+/*!
+ * \~chinese \brief 选择第一项
+ */
 void DSimpleListView::selectFirstItem()
 {
     D_D(DSimpleListView);
@@ -483,6 +552,9 @@ void DSimpleListView::selectFirstItem()
     repaint();
 }
 
+/*!
+ * \~chinese \brief 选择最后一项
+ */
 void DSimpleListView::selectLastItem()
 {
     D_D(DSimpleListView);
@@ -504,42 +576,53 @@ void DSimpleListView::selectLastItem()
     repaint();
 }
 
+/*!
+ * \~chinese \brief 移动到上一项
+ */
 void DSimpleListView::selectPrevItem()
 {
-    D_D(DSimpleListView);
-
     selectPrevItemWithOffset(1);
 }
 
+/*!
+ * \~chinese \brief 移动到下一项
+ */
 void DSimpleListView::selectNextItem()
 {
-    D_D(DSimpleListView);
-
     selectNextItemWithOffset(1);
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到下一页的项
+ */
 void DSimpleListView::shiftSelectPageDown()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         shiftSelectNextItemWithOffset(getScrollAreaHeight() / d->rowHeight);
     }
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到上一页的项
+ */
 void DSimpleListView::shiftSelectPageUp()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         shiftSelectPrevItemWithOffset(getScrollAreaHeight() / d->rowHeight);
     }
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到末尾项
+ */
 void DSimpleListView::shiftSelectToEnd()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         // Select last item if nothing selected yet.
         if (d->selectionItems->empty()) {
@@ -561,10 +644,13 @@ void DSimpleListView::shiftSelectToEnd()
 
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到起始项
+ */
 void DSimpleListView::shiftSelectToHome()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         // Select first item if nothing selected yet.
         if (d->selectionItems->empty()) {
@@ -586,24 +672,33 @@ void DSimpleListView::shiftSelectToHome()
 
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到下一项
+ */
 void DSimpleListView::shiftSelectToNext()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         shiftSelectNextItemWithOffset(1);
     }
 }
 
+/*!
+ * \~chinese \brief 从当前项选择到上一项
+ */
 void DSimpleListView::shiftSelectToPrev()
 {
     D_D(DSimpleListView);
-    
+
     if (!d->isSingleSelect) {
         shiftSelectPrevItemWithOffset(1);
     }
 }
 
+/*!
+ * \~chinese \brief 滚动到下一页
+ */
 void DSimpleListView::scrollPageDown()
 {
     D_D(DSimpleListView);
@@ -611,6 +706,9 @@ void DSimpleListView::scrollPageDown()
     selectNextItemWithOffset(getScrollAreaHeight() / d->rowHeight);
 }
 
+/*!
+ * \~chinese \brief 滚动到上一页
+ */
 void DSimpleListView::scrollPageUp()
 {
     D_D(DSimpleListView);
@@ -685,8 +783,6 @@ bool DSimpleListView::eventFilter(QObject *, QEvent *)
 
 void DSimpleListView::keyPressEvent(QKeyEvent *keyEvent)
 {
-    D_D(DSimpleListView);
-
     if (keyEvent->key() == Qt::Key_Home) {
         if (keyEvent->modifiers() == Qt::ControlModifier) {
             ctrlScrollToHome();
